@@ -7,8 +7,11 @@ from ssb_altinn3_util.clients.decorators.simple_exception_wrapper import (
 
 
 class GuardianClient:
-    def __init__(self):
-        self.token_endpoint = f"http://maskinporten-guardian.dapla.svc.cluster.local/maskinporten/access-token"
+    def __init__(self, base_url: str):
+        if not base_url:
+            self.token_endpoint = "http://maskinporten-guardian.dapla.svc.cluster.local/maskinporten/access-token"
+        else:
+            self.token_endpoint = f"{base_url}/maskinporten/access-token"
 
     @exception_handler("Guardian Client")
     def get_token(self, keycloak_token: str) -> str:
