@@ -8,6 +8,7 @@ def init_db_adapter(
     project_id: str,
     spanner_instance_id: str,
     user_password: str = None,
+    in_memory: bool = False,
 ) -> AltinnMottakDbAdapter:
     """
     Initiates the database adapter enabling database storage through the database.crud module
@@ -19,6 +20,7 @@ def init_db_adapter(
     :param spanner_instance_id: If Spanner is used, provide the Spanner instance-id
     :param user_password: Password for the database user.  Only required when using local database or ordinary database
     authentication.
+    :param in_memory: If set to True a sqllite instance for in_memory use is created
     :return: A configured data adapter ready for use.
     """
     adapter = AltinnMottakDbAdapter()
@@ -28,6 +30,7 @@ def init_db_adapter(
         database_name=database_name,
         spanner_instance_id=spanner_instance_id,
         project_id=project_id,
+        in_memory=in_memory,
     )
     schema.AltinnMottakDbAdapter.Base.metadata.create_all(bind=adapter.engine)
     return adapter
